/**
 * Returns a function that does the same work as aFunction, using aObject as
 * its "this" object.
 *
 * @param aFunction
 *        The function to be bound to aObject.
 * @param aObject
 *        The object to act at the "this" object for the returned function.
 */
function bind(aFunction, aObject)
{
  return function() {
    var args = [];
    for (var i = 0; i < arguments.length; i++) {
      args.push(arguments[i]);
    }
    aFunction.apply(aObject, args);
  }
}
/* -or */
function bind(aFunction, aObject)
{
  return function() {
    aFunction.apply(aObject, Array.slice(arguments));
  }
}
/* this works in Firefox, but may not work in different browsers (untested) */
function bind(aFunction, aObject)
{
  return function() {
    aFunction.apply(aObject, arguments);
  }
}
